@@ -137,8 +137,8 @@ void gvir_config_storage_pool_set_source(GVirConfigStoragePool *pool,
     g_return_if_fail(GVIR_CONFIG_IS_STORAGE_POOL(pool));
     g_return_if_fail(GVIR_CONFIG_IS_STORAGE_POOL_SOURCE(source));
 
-    gvir_config_object_attach(GVIR_CONFIG_OBJECT(pool),
-                              GVIR_CONFIG_OBJECT(source));
+    gvir_config_object_attach_replace(GVIR_CONFIG_OBJECT(pool),
+                                      GVIR_CONFIG_OBJECT(source));
 }
 
 void gvir_config_storage_pool_set_target(GVirConfigStoragePool *pool,
@@ -147,6 +147,6 @@ void gvir_config_storage_pool_set_target(GVirConfigStoragePool *pool,
     g_return_if_fail(GVIR_CONFIG_IS_STORAGE_POOL(pool));
     g_return_if_fail(GVIR_CONFIG_IS_STORAGE_POOL_TARGET(target));
 
-    gvir_config_object_attach(GVIR_CONFIG_OBJECT(pool),
-                              GVIR_CONFIG_OBJECT(target));
+    gvir_config_object_attach_replace(GVIR_CONFIG_OBJECT(pool),
+                                      GVIR_CONFIG_OBJECT(target));
 }
